location_plat/location_data_harvester_api/inc/maptilegeocoderplugin.h
changeset 26 f3533f6eae3f
parent 20 cd10d5b85554
--- a/location_plat/location_data_harvester_api/inc/maptilegeocoderplugin.h	Thu May 27 12:49:34 2010 +0300
+++ b/location_plat/location_data_harvester_api/inc/maptilegeocoderplugin.h	Fri Jun 11 13:33:47 2010 +0300
@@ -133,8 +133,9 @@
      * @param aSize requested maptile size
      *
      */
-    TMapTileParam( const TReal aLatitude, const TReal aLongitude, const TInt aZoom, const TInt aSize ):
-        iLattitude( aLatitude ), iLongitude( aLongitude ), iZoomLevel( aZoom ), iSize( aSize )
+    TMapTileParam( const TReal aLatitude, const TReal aLongitude, 
+            const TInt aZoom, const TInt aWidth, const TInt aHeight ): iLattitude( aLatitude ),
+            iLongitude( aLongitude ), iZoomLevel( aZoom ), iWidth( aWidth ), iHeight( aHeight )
     {
     }
 		
@@ -155,8 +156,10 @@
     TReal iLongitude;
     //Zoom level
     TInt iZoomLevel;
-    //Required image size
-    TInt iSize;
+    //Required image width
+    TInt iWidth;
+    //Required image height
+    TInt iHeight;
 };